const isSigner = value => {
  return 'publicKey' in value;
};
const createSignerFromKeypair = (context, keypair) => {
  return {
    publicKey: keypair.publicKey,
    async signMessage(message) {
      return context.eddsa.sign(message, keypair);
    },
    async signTransaction(transaction) {
      transaction.sign([keypair]);
      return transaction;
    },
    async signAllTransactions(transactions) {
      return Promise.all(transactions.map(transaction => this.signTransaction(transaction)));
    }
  };
};
class NullSigner {
  // TODO(loris): Custom errors.
  get publicKey() {
    throw new Error('Method not implemented.');
  }
  signMessage() {
    throw new Error('Method not implemented.');
  }
  signTransaction() {
    throw new Error('Method not implemented.');
  }
  signAllTransactions() {
    throw new Error('Method not implemented.');
  }
}

export { NullSigner, createSignerFromKeypair, isSigner };
//# sourceMappingURL=Signer.mjs.map
